External documentation — Pootle 2.6.1 documentation

# External documentation

These are external sources of documentation, often relevant to a specific Pootle server for one of the many projects that use Pootle.

- https://taoeffect.s3.amazonaws.com/other/Pootle_Tutorial.pdf
- http://colivre.coop.br/Tech/TraducaoPootle
- http://wiki.creativecommons.org/Translating_with_Pootle
- http://wiki.openoffice.org/wiki/Pootle_User_Guide
- http://wiki.openoffice.org/wiki/Pootle_Glossary_Guide
- http://mr-dust.pe.kr/entry/How-to-translate-OpenOfficeorg
- http://docs.linux.org.ua/Dlou/index.php/Pootle (Ukrainian, Українська)
- http://takanory.net/plone/japanese/pootle (Japanese, 日本語)
- http://www.moongift.jp/2006/09/2326/ (Japanese, 日本語)
- http://gustavonarea.net/blog/posts/installing-pootle-on-debian-etch-the-easiest-way/
- http://wiki.laptop.org/go/Pootle (OLPC project)
- http://wiki.list.org/display/DEV/Pootle+primer (mailman project)
- http://wiki.squid-cache.org/Translations/Basics (Squid project)
- http://pe.sugarlabs.org/ir/Manual%20de%20Traducci%C3%B3n%20de%20Sugar (Spanish, Español)